<?php

$LANG = array(

'L_LANGUE'						=> 'pl',

'L_DATE_CREATION'				=> 'Data utworzenia',
'L_DATE_UPDATE'					=> 'Data zaktualizowane',

# common
'L_PLUXML_VERSION'				=> 'Wersja PluXml',
'L_HOMEPAGE'					=> 'Strona startowa',
'L_UNCLASSIFIED'				=> 'Bez kategorii',
'L_INFO_PHP_VERSION'			=> 'Wersja PHP',
'L_INFO_MAGIC_QUOTES'			=> 'Stan "magicznych cudzysłowów"',
'L_INFO_CHARSET'				=> 'kodowanie',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Nie odnaleziono głównego szablonu PluXml',
'L_ERR_FILE_NOTFOUND'			=> 'Plik docelowy nie został znaleziony',
'L_ERR_PAGE_NOT_FOUND'			=> 'Nie znaleziono strony',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'styczeń',
'L_SHORT_FEBRUARY'				=> 'luty',
'L_SHORT_MARCH'					=> 'marzec',
'L_SHORT_APRIL'					=> 'kwiecień',
'L_SHORT_MAY'					=> 'maj',
'L_SHORT_JUNE'					=> 'czerwiec',
'L_SHORT_JULY'					=> 'lipiec',
'L_SHORT_AUGUST'				=> 'sierpień',
'L_SHORT_SEPTEMBER'				=> 'wrzesień',
'L_SHORT_OCTOBER'				=> 'pażdziernik',
'L_SHORT_NOVEMBER'				=> 'listopad',
'L_SHORT_DECEMBER'				=> 'grudzień',
'L_JANUARY'						=> 'styczeń',
'L_FEBRUARY'					=> 'luty',
'L_MARCH'						=> 'marzec',
'L_APRIL'						=> 'kwiecień',
'L_MAY'							=> 'maj',
'L_JUNE'						=> 'czerwiec',
'L_JULY'						=> 'lipiec',
'L_AUGUST'						=> 'sierpień',
'L_SEPTEMBER'					=> 'wrzesień',
'L_OCTOBER'						=> 'pażdziernik',
'L_NOVEMBER'					=> 'listopad',
'L_DECEMBER'					=> 'grudzień',
'L_MONDAY'						=> 'poniedziałek',
'L_TUESDAY'						=> 'wtorek',
'L_WEDNESDAY'					=> 'środa',
'L_THURSDAY'					=> 'czwartek',
'L_FRIDAY'						=> 'piątek',
'L_SATURDAY'					=> 'sobota',
'L_SUNDAY'						=> 'niedziela',

# class.plx.capcha.php
'L_LAST'						=> 'ostatnia',
'L_FIRST'						=> 'pierwsza',
'L_SECOND'						=> 'druga',
'L_THIRD'						=> 'trzecia',
'L_FOURTH'						=> 'czwarta',
'L_FIFTH'						=> 'piąta',
'L_SIXTH'						=> 'szósta',
'L_SEVENTH'						=> 'siódma',
'L_EIGTH'						=> 'ósma',
'L_NINTH'						=> 'dziewiąta',
'L_TENTH'						=> 'dziesiąta',
'L_NTH'							=> 'n-ta',
'L_CAPCHA_QUESTION'				=> 'Jaka jest <span class="capcha-letter">%s</span> litera w słowie <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s jest zapisywalny',
'L_WRITE_NOT_ACCESS'			=> '%s nie posiada prawa do zapisu lub nie istnieje',
'L_MODREWRITE_AVAILABLE'		=> 'Moduł apache mod_rewrite jest dostępny',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Moduł apache mod_rewrite nie jest dostępny',
'L_LIBGD_INSTALLED'				=> 'Zainstalowane biblioteki GD',
'L_LIBGD_NOT_INSTALLED'			=> 'Nie zainstalowane biblioteki GD',
'L_LIBXML_INSTALLED'			=> 'Zainstalowane biblioteki XML',
'L_LIBXML_NOT_INSTALLED'		=> 'Nie zainstalowane biblioteki XML',
'L_MAIL_AVAILABLE'				=> 'Funkcja wysyłania poczty dostępna',
'L_MAIL_NOT_AVAILABLE'			=> 'Funkcja wysyłania poczty nie jest dostępna',

# class.plx.motor.php
'L_ARTICLE_NO_TAG'				=> 'Brak postów dla danego słowa kluczowego !',
'L_UNKNOWN_CATEGORY'			=> 'Ta kategoria nie istnieje !',
'L_NO_ARTICLE_PAGE'				=> 'Brak postów dla tej strony !',
'L_UNKNOWN_ARTICLE'				=> 'Ten post nie istniał lub nie istnieje już !',
'L_COM_IN_MODERATION'			=> 'Komentarz jest sprawdzany przez administratora tej strony',
'L_UNKNOWN_STATIC'				=> 'Ta strona nie istniała lub nie istnieje już !',
'L_DOCUMENT_NOT_FOUND'			=> 'Podany dokument nie został znaleziony',
'L_NEWCOMMENT_ERR'				=> 'Wystąpił błąd podczas publikacji tego komentarza',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Proszę wypełnić wszystkie wymagane pola',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'Błędna weryfikacja antyspamowa',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Kompresja %s aktywna',
'L_PAGETITLE_ARCHIVES'			=> 'Archiwum',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'brak kategorii',
'L_CATEGORY'					=> 'kategorii',
'L_CATEGORIES'					=> 'kategorie',
'L_NO_ARTICLE'					=> 'brak posta',
'L_ARTICLE'						=> 'post',
'L_ARTICLES'					=> 'posty',
'L_ARTAUTHOR_UNKNOWN'			=> 'brak danych',
'L_ARTTAGS_NONE'				=> 'brak',
'L_ARTCHAPO'					=> 'Czytaj więcej',
'L_ARTFEED_RSS_CATEGORY'		=> 'Kanał RSS z kategorii',
'L_ARTFEED_RSS_TAG'				=> 'Kanał RSS z tagu',
'L_ARTFEED_RSS'					=> 'Kanał RSS z posta',
'L_NO_COMMENT'					=> 'brak komentarzy',
'L_COMMENT'						=> 'komentarz',
'L_COMMENTS'					=> 'komentarze',
'L_COMFEED_RSS_ARTICLE'			=> 'Kanał RSS z komentarzy dla tego posta',
'L_COMFEED_RSS'					=> 'Kanał RSS z komentarzy',
'L_STATICCONTENT_INPROCESS'		=> 'Ta strona jest obecnie moderowana',
'L_SAID'						=> 'mówi',

'L_PAGINATION_FIRST_TITLE'		=> 'Przejdź do pierwszej strony',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Poprzednia strona',
'L_PAGINATION_PREVIOUS'			=> 'poprzednia',
'L_PAGINATION_NEXT_TITLE'		=> 'Następna strona',
'L_PAGINATION_NEXT'				=> 'następna',
'L_PAGINATION_LAST_TITLE'		=> 'Przejdź do ostatniej strony',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'strona %s z %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Prywatne adresy URL nie zostały zainicjowane w ustawieniach administracji !',
'L_FEED_COMMENTS'				=> 'Komentarze',
'L_FEED_ONLINE_COMMENTS'		=> 'Aktywne komentarze',
'L_FEED_OFFLINE_COMMENTS'		=> 'Nieaktywne komentarze',
'L_FEED_WRITTEN_BY'				=> 'Napisane przez',

);
?>
